@@ -180,6 +180,7 @@ done:
 				passphrase_reply->user_data);
 	connman_service_unref(passphrase_reply->service);
 	dbus_message_unref(reply);
+	dbus_pending_call_unref(call);
 	g_free(passphrase_reply);
 }
 
@@ -401,8 +402,11 @@ int __connman_agent_request_passphrase_input(struct connman_service *service,
 					request_input_append_identity, service);
 	}
 
-	connman_dbus_dict_append_dict(&dict, "Passphrase",
-				request_input_append_passphrase, service);
+	if (__connman_service_get_security(service) !=
+			CONNMAN_SERVICE_SECURITY_NONE) {
+		connman_dbus_dict_append_dict(&dict, "Passphrase",
+					request_input_append_passphrase, service);
+	}
 
 	if (__connman_service_wps_enabled(service) == TRUE) {
 	    connman_dbus_dict_append_dict(&dict, "WPS",
