@@ -196,6 +196,7 @@ int __connman_resolver_init(connman_bool_t dnsproxy);
 void __connman_resolver_cleanup(void);
 int __connman_resolvfile_append(const char *interface, const char *domain, const char *server);
 int __connman_resolvfile_remove(const char *interface, const char *domain, const char *server);
+int __connman_resolver_redo_servers(const char *interface);
 
 void __connman_storage_migrate(void);
 GKeyFile *__connman_storage_open_global();
@@ -295,7 +296,8 @@ enum connman_ipconfig_type __connman_ipconfig_get_config_type(
 					struct connman_ipconfig *ipconfig);
 unsigned short __connman_ipconfig_get_type_from_index(int index);
 unsigned int __connman_ipconfig_get_flags_from_index(int index);
-const char *__connman_ipconfig_get_gateway_from_index(int index);
+const char *__connman_ipconfig_get_gateway_from_index(int index,
+	enum connman_ipconfig_type type);
 void __connman_ipconfig_set_index(struct connman_ipconfig *ipconfig, int index);
 
 const char *__connman_ipconfig_get_local(struct connman_ipconfig *ipconfig);
@@ -692,10 +694,10 @@ void __connman_notifier_cleanup(void);
 void __connman_notifier_service_add(struct connman_service *service,
 					const char *name);
 void __connman_notifier_service_remove(struct connman_service *service);
-void __connman_notifier_online(enum connman_service_type type);
+void __connman_notifier_enter_online(enum connman_service_type type);
+void __connman_notifier_leave_online(enum connman_service_type type);
 void __connman_notifier_connect(enum connman_service_type type);
-void __connman_notifier_disconnect(enum connman_service_type type,
-					enum connman_service_state old_state);
+void __connman_notifier_disconnect(enum connman_service_type type);
 void __connman_notifier_offlinemode(connman_bool_t enabled);
 void __connman_notifier_default_changed(struct connman_service *service);
 void __connman_notifier_proxy_changed(struct connman_service *service);
