@@ -23,6 +23,7 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
@@ -109,7 +110,7 @@ static connman_bool_t wext_interface(char *ifname)
 	struct iwreq wrq;
 	int fd, err;
 
-	fd = socket(PF_INET, SOCK_DGRAM, 0);
+	fd = socket(PF_INET, SOCK_DGRAM | SOCK_CLOEXEC, 0);
 	if (fd < 0)
 		return FALSE;
 
@@ -290,7 +291,9 @@ static void trigger_rtnl(int index, void *user_data)
 	}
 
 	if (rtnl->newgateway) {
-		const char *gateway = __connman_ipconfig_get_gateway_from_index(index);
+		const char *gateway =
+			__connman_ipconfig_get_gateway_from_index(index,
+					CONNMAN_IPCONFIG_TYPE_ALL);
 
 		if (gateway != NULL)
 			rtnl->newgateway(index, gateway);
@@ -600,6 +603,20 @@ static void process_newaddr(unsigned char family, unsigned char prefixlen,
 
 	__connman_ipconfig_newaddr(index, family, label,
 					prefixlen, ip_string);
+
+	if (family == AF_INET6) {
+		/*
+		 * Re-create RDNSS configured servers if there are any
+		 * for this interface. This is done because we might
+		 * have now properly configured interface with proper
+		 * autoconfigured address.
+		 */
+		char *interface = connman_inet_ifname(index);
+
+		__connman_resolver_redo_servers(interface);
+
+		g_free(interface);
+	}
 }
 
 static void process_deladdr(unsigned char family, unsigned char prefixlen,
@@ -1567,7 +1584,7 @@ int __connman_rtnl_init(void)
 	interface_list = g_hash_table_new_full(g_direct_hash, g_direct_equal,
 							NULL, free_interface);
 
-	sk = socket(PF_NETLINK, SOCK_DGRAM, NETLINK_ROUTE);
+	sk = socket(PF_NETLINK, SOCK_DGRAM | SOCK_CLOEXEC, NETLINK_ROUTE);
 	if (sk < 0)
 		return -1;
 
