@@ -292,41 +292,6 @@ static const char *get_name(enum connman_service_type type)
 	return NULL;
 }
 
-static void load_state(struct connman_technology *technology)
-{
-	GKeyFile *keyfile;
-	gchar *identifier;
-	GError *error = NULL;
-	connman_bool_t enable;
-
-	DBG("technology %p", technology);
-
-	keyfile = __connman_storage_load_global();
-	/* Fallback on disabling technology if file not found. */
-	if (keyfile == NULL) {
-		technology->enable_persistent = FALSE;
-		return;
-	}
-
-	identifier = g_strdup_printf("%s", get_name(technology->type));
-	if (identifier == NULL)
-		goto done;
-
-	enable = g_key_file_get_boolean(keyfile, identifier, "Enable", &error);
-	if (error == NULL)
-		technology->enable_persistent = enable;
-	else {
-		technology->enable_persistent = FALSE;
-		g_clear_error(&error);
-	}
-done:
-	g_free(identifier);
-
-	g_key_file_free(keyfile);
-
-	return;
-}
-
 static void save_state(struct connman_technology *technology)
 {
 	GKeyFile *keyfile;
@@ -355,6 +320,50 @@ done:
 	return;
 }
 
+static void load_state(struct connman_technology *technology)
+{
+	GKeyFile *keyfile;
+	gchar *identifier;
+	GError *error = NULL;
+	connman_bool_t enable;
+
+	DBG("technology %p", technology);
+
+	keyfile = __connman_storage_load_global();
+	/* Fallback on disabling technology if file not found. */
+	if (keyfile == NULL) {
+		if (technology->type == CONNMAN_SERVICE_TYPE_ETHERNET)
+			/* We enable ethernet by default */
+			technology->enable_persistent = TRUE;
+		else
+			technology->enable_persistent = FALSE;
+		return;
+	}
+
+	identifier = g_strdup_printf("%s", get_name(technology->type));
+	if (identifier == NULL)
+		goto done;
+
+	enable = g_key_file_get_boolean(keyfile, identifier, "Enable", &error);
+	if (error == NULL)
+		technology->enable_persistent = enable;
+	else {
+		if (technology->type == CONNMAN_SERVICE_TYPE_ETHERNET)
+			technology->enable_persistent = TRUE;
+		else
+			technology->enable_persistent = FALSE;
+
+		save_state(technology);
+		g_clear_error(&error);
+	}
+done:
+	g_free(identifier);
+
+	g_key_file_free(keyfile);
+
+	return;
+}
+
 connman_bool_t __connman_technology_get_offlinemode(void)
 {
 	return global_offlinemode;
@@ -387,12 +396,12 @@ static connman_bool_t connman_technology_load_offlinemode()
 	/* If there is a error, we enable offlinemode */
 	keyfile = __connman_storage_load_global();
 	if (keyfile == NULL)
-		return TRUE;
+		return FALSE;
 
 	offlinemode = g_key_file_get_boolean(keyfile, "global",
 						"OfflineMode", &error);
 	if (error != NULL) {
-		offlinemode = TRUE;
+		offlinemode = FALSE;
 		g_clear_error(&error);
 	}
 
@@ -1346,6 +1355,9 @@ int __connman_technology_init(void)
 
 	global_offlinemode = connman_technology_load_offlinemode();
 
+	/* This will create settings file if it is missing */
+	connman_technology_save_offlinemode();
+
 	return 0;
 }
 
