@@ -150,7 +150,7 @@ int main(int argc, char *argv[])
 
 	timer = g_timer_new();
 
-	if (g_web_request_get(web, argv[1], web_result, NULL) == 0) {
+	if (g_web_request_get(web, argv[1], web_result, NULL,  NULL) == 0) {
 		fprintf(stderr, "Failed to start request\n");
 		return 1;
 	}
